********************************************************************************
*************** Redes analíticas. Grafos de coincidencias y regresión **********
********************************************************************************
****************************** Madrid. CIS. 2023 *******************************
********************************************************************************
****************************** Capítulo 2 - Ejercicio 2.1 **********************


****** Pasos previos ******

version 17
*ssc install tab_chi
*net install coin, from("http://casus.usal.es/stata")
cls
// Carga de datos
use "data/ESE8.dta", clear


****** Aparatado: Coincidencias y tablas de contingencia ******

// Preparación de las variables
rename f5 vive_pareja
rename c11 creyente
label define sino 1 "sí" 2 "no", modify
label value vive_pareja creyente sino
foreach var of varlist vive_pareja creyente {
    label variable `var' `var'
    local i = `i' + 1
    rename `var' `var'`i'
}

// Tabla cruzada con frecuencias absolutas
tabulate vive_pareja creyente

// Tabla cruzada con porcentajes totales
tabulate vive_pareja creyente, nofreq cell

// Tabla cruzada con porcentajes verticales
tabulate vive_pareja creyente, nofreq column

// Tabla cruzada con porcentajes horizontales
tabulate vive_pareja creyente, nofreq row

// Tabla cruzada con frecuencias reales y esperadas 
tabulate vive_pareja creyente, freq expected

// Tabla cruzada con residuos de celda, estandarizados y ajustados
tabchi vive_pareja creyente, noo noe raw pearson adjust
* +chi2 & V de Cramer.


****** Aparatado: Tablas mayores de 2×2 de dos variables ******

// Preparación de las variables
recode c12 (.a=0 "Sin religión") (2/8=2 "Otra") (1=1 "Católico romano"), gen(religion)
recode f11 (.a 1= 2 "Casado/Vive con pareja")(3 4 = 3 "Separado/a-Divorciado/a") (5 = 4 "Viudo/a" ) (6 = 1  "Soltero/a"), gen(estado_civil)

capture drop solteria divorcio sin_relig otra_relig
gen solteria=  (1 - (estado_civil==1)) +1  if !missing(estado_civil)
gen divorcio= (1 - (estado_civil==4)) +1 if !missing(estado_civil)
gen sin_relig=  (1 - (religion==0)) +1 if !missing(religion)
gen otra_relig= (1 - (religion==2)) if !missing(religion)
label define sino 1 "sí" 2 "no", modify
label value solteria-otra_relig sino


foreach var of varlist estado_civil religion solteria-otra_relig {
    label variable `var' `var'
    local i = `i' + 1
    rename `var' `var'`i'
}


// Tabla cruzada con frecuencias absolutas
tabulate estado_civil religion

// Tabla cruzadacon residuos ajustados
tabchi estado_civil religion, noo noe adj

// Coincidencias condicionales.
table solteria sin_relig, nototals
tabchi solteria sin_relig, noo noe adj
table divorcio, nototals
tabchi divorcio otra_relig, noo noe adj


****** Aparatado: Tablas de variables dicotómicas múltiples ******

// Preparación de las variables
label var c19a "d_raza"
label var c19b "d_nacionalidad"
label var c19c "d_religion"
label var c19d "d_idioma"
label var c19e "d_grupo_etnico"
label var c19f "d_edad"
label var c19g "d_genero"
label var c19h "d_sexualidad"
label var c19i "d_discapacidad"
label var c19j "d_otras"
label var c19m "d_sin_discriminacion"

foreach v of varlist c19a-c19j {
   local x : variable label `v'
   rename `v' `x'
}

// Cruce de respuesta múltiple: Frecuencias 
coin d_*, f

// Cruce de respuesta múltiple: Residuos ajustados 
coin d_*, expected

// Cruce de respuesta múltiple: Probabilidad de Fischer
coin d_*, pfisher 

// Cruce de respuesta múltiple: Residuos normalizados
coin d_*, pnormalized

// Cruce de respuesta múltiple: Fisher ajustadas por Bonferroni 
coin d_*,  pfisher bonferroni


****** Aparatado: Tablas de múltiples variables ******

// Tabla Burt: Frecuencias
coin i.creyente i.estado_civil d_*, f

// Tabla Burt: Fisher ajustadas por Bonferroni
coin i.creyente i.estado_civil d_*, pfisher bonferroni

// Tabla Burt: Residuos ajustados
coin i.creyente i.estado_civil d_*, normalized
