# ********************************************************************************
# *************** Redes analíticas. Grafos de coincidencias y regresión **********
# ********************************************************************************
# ****************************** Madrid. CIS. 2023 *******************************
# ********************************************************************************
# ****************************** Capítulo 2 - Ejercicio 2.3 **********************

######################## a)  Tablas

# Cargamos el paquete necesario y leemos el fichero SPSS.
library(haven)
C3190 <- read_sav("data/3190.sav")

# Seleccionamos las columnas relevantes y las almacenamos en un nuevo data frame.
X <- subset(C3190, select=(c("P13_1", "P13_2", "P13_3", "P13_4", "P13_5")))

# Cambiamos los nombres de las variables por sus etiquetas.
names(X) <- sapply(X, attr,"label")

# Convertimos las variables en factores y eliminamos las etiquetas sin frecuencias.
Y <- droplevels(as_factor(X))

# Con ifelse se puede realizar sencillas recodificaciones de las variables.
Y$Estudios <-ifelse(C3190$ESTUDIOS==6, 1, ifelse(C3190$ESTUDIOS==9, NA, 2))
# Con factor se le asignas etiquetas.
Y$Estudios <- factor(Y$Estudios, levels=c(1, 2), labels=c("Superiores", "Hasta secundarios"))

# Generamos tablas cruzadas para cada variable y calculamos los porcentajes verticales.
t1 <- ftable(Y[,c(1,6)])
round(prop.table(t1, margin=2)*100,2)

# Repetimos este proceso para cada variable.
t2 <- ftable(Y[,c(2,6)])
round(prop.table(t2, margin=2)*100,2)
t3 <- ftable(Y[,c(3,6)])
round(prop.table(t3, margin=2)*100,2)
t4 <- ftable(Y[,c(4,6)])
round(prop.table(t4, margin=2)*100,2)
t5 <- ftable(Y[,c(5,6)])
round(prop.table(t5, margin=2)*100,2)


######################## b)  Significación

# Realizamos la prueba Chi-cuadrado para comprobar la hipótesis.
chi1 <- chisq.test(t1); chi1; chi1$stdres

# Repetimos este proceso para cada variable.
chi2 <- chisq.test(t2); chi2; chi2$stdres
chi3 <- chisq.test(t3); chi3; chi3$stdres
chi4 <- chisq.test(t4); chi4; chi4$stdres
chi5 <- chisq.test(t5, correct=FALSE); chi5; chi5$stdres

# Nótese que el residuo normalizado al cuadrado es idéntico al chi2 sin corrección de Yates
abs(chi5$statistic-chi5$stdres[1]^2) < 1.0e-10


######################## c) Matriz de incidencias

# Convertimos las variables en numéricas y mostramos los 10 primeros casos.
I <- 2-sapply(Y, as.numeric)
colnames(I)[6] <- "Estudios: superiores"
head(I, 10)

######################## d) Tratamiento

# Cargamos el paquete necesario y convertimos la matriz de incidencias en una matriz de coincidencias.
library(netCoin)
C <- coin(I)

# Calculamos las frecuencias relativas, los porcentajes verticales y los residuos normalizados de Haberman.
sim(C, procedures="x")
sim(C, procedures="i")
sim(C, procedures="h")


######################## e) Gráfico de coincidencias

# Generamos el gráfico reticular de coincidencias.
plot(allNet(I, lwidth="Haberman"), dir="~/temp")
