********************************************************************************
*************** Redes analíticas. Grafos de coincidencias y regresión **********
********************************************************************************
****************************** Madrid. CIS. 2023 *******************************
********************************************************************************
****************************** Capítulo 3 - Ejercicio 3.2 **********************

**** a) Pasos previos ****
version 17

** Opciones de gráficos para que salgan con fondo blanco
global white graphregion(lcolor(white) ilcolor(white) fcolor(white) ifcolor(white) style(none) lwidth(none)) plotregion(lcolor(white) ilcolor(white) style(none) lwidth(none))

** Crea un marco para alojar los datos
clear frames
frame create var
frame change var

** Importa los datos de la hoja de cálculo
import excel "data\datos.xlsx", sheet("data") firstrow case(lower) clear

** Transpone los datos para calcular distancia entre variables en lugar de casos
xpose, clear format promote varname

** Cambia los nombres de las unidades (en este caso variables). Útil para etiquetar los conglomerados.
replace _varname="Gen." if _varname=="xg"
replace _varname="Loc." if _varname=="xl"
replace _varname="TV"   if _varname=="xt"
replace _varname="Int." if _varname=="xi"
replace _varname="Rec." if _varname=="xr"
replace _varname="Vot." if _varname=="xv"
replace _varname="Caz." if _varname=="xc"
replace _varname="Eut." if _varname=="xe"


**** b) Cálculo de matrices de distancias

matrix dissimilarity L2=v1-v10, L2
matrix dissimilarity G2=v1-v10, Gower2
matrix dissimilarity G=v1-v10, Gower
matrix dissimilarity J=v1-v10, Jaccard
matrix dissimilarity L1=v1-v10, L1
matrix dissimilarity LI=v1-v10, Linfinity
matrix dissimilarity Canberra=v1-v10, Canberra
matrix dissimilarity Angle=v1-v10, angle
matrix dissimilarity Corr=v1-v10, corr

local nombres Gen Loc TV Int Rec Vot Caz Eut
local matrices L2 G2 G J L1 LI Canberra Angle Corr
foreach matrix of local matrices {
	matrix colnames `matrix'= `nombres'
	matrix rownames `matrix'= `nombres'
	matlist `matrix', title(`matrix') format(%5.1f)
}

**** c) Demostrar que K-Means da resultados distintos cada vez que se ejecuta.
keep in 1/8
capture: cluster drop C*
set seed 10
forvalues X=1/10 {
cluster kmeans v1- v10, k(2) measure(L2) name(C`X')
replace C`X'=C`X'-1
}
list C1-C10

* Los resultados serían idénticos si se pusiera la semilla aleatoria en la línea anterior a la instrucción cluster.

* Solución 1ª: definir nodos inciales: En este caso las dos últimas variables (casos): caza y eutanasia
keep in 1/8
expand 2 if _n > 6 // Añade los dos casos últimos casos (tantos como grupos se quieren formar)
capture: cluster drop C*
cluster kmeans v1- v10, k(2) measure(Gower) name(C1) start(lastk, exclude)
table C1 _varname
cluster kmeans v1- v10, k(2) measure(matching) name(C2) start(lastk, exclude) keep
table C2 _varname
table C2 C1

* Solución 2ª: definir nodos inciales: En este otro otras dos variables (casos): Generales y Votar derecha.
keep in 1/8
expand 2 if _n==1 | _n==6 // Añade el primer y el sexto casos (tantos como grupos se quieren formar)
cluster kmeans v1- v10, k(2) measure(matching) name(C3) start(lastk, exclude)
cluster kmeans v1- v10, k(2) measure(jaccard) name(C4) start(lastk, exclude)
cluster kmeans v1- v10, k(2) measure(L2) name(C5) start(lastk, exclude)
by C5, sort: list _varname C?

* Se vuelve a las 8 unidades (variables) iniciales.
keep in 1/8

* Elaboración de conglomerados jerárquicos 4 distancias X 4 métodos de aglomeración
capture: drop single-wards
local distances Russell Jaccard matching L2
local D1 "Russell y Rao" 
local D2 "Jaccard" 
local D3 "Rogers y Tanimoto" 
local D4 "Euclídea"
local D 0
local methods single complete waverage wards
local metodos mínimas máximas medias varianzas
foreach Y of local distances {
local D `++D'
matrix dissimilarity `Y'=v1-v10, `Y' dissim(oneminus)
if (`"`Y'"'=="Russell")  matrix Russell=Russell-diag(vecdiag(Russell))
if (`"`Y'"'=="Pearson") matrix `Y'=`Y'/2
if (`"`Y'"'=="L2") matrix `Y'=`Y'/sqrt(10)
capture: cluster drop `methods'
capture: drop `methods'
local M 1
foreach X of local methods {
clustermat `X' `Y', add name(`X')

capture: cluster gen `X'=groups(2), name(`X')
di `"-`:word `M' of `metodos''-"'
di `"`D`D''"'
capture: cluster dendrogram `X', labels(_varname) name(`Y'`X', replace) title(`"-`:word `M++' of `metodos''-"') ///
         ylabel(0(.20)1) xlabel(, labsize(small)) ///
         ytitle(`"`D`D''"') scheme(Tufte)
}
di "`Y'"
if ("`Y'"=="Russell") { //Como el cluster hecho con el algoritmo Wards y la medida Russell y Rao no funciona no se le combina.
	 graph combine `Y'single `Y'complete `Y'waverage, name(`Y', replace) title(`"`D`D''"') scheme(Tufte) imargin(zero) hole(4)
}
else {
 graph combine `Y'single `Y'complete `Y'waverage `Y'wards, name(`Y', replace) title(`"`D`D''"') scheme(Tufte) imargin(zero)
}
}
graph combine `distances', name(Todo, replace) scheme(Tufte)


