# ********************************************************************************
# *************** Redes analíticas. Grafos de coincidencias y regresión **********
# ********************************************************************************
# ****************************** Madrid. CIS. 2023 *******************************
# ********************************************************************************
# ****************************** Capítulo 4 - Ejercicio 4.1 **********************

# 4. Gráficos de coincidencias ----

# Principales objetos:
# Unamuno: Marco de datos con matriz de incidencias. 329 casos (fotos) y 31 variables binarias (personajes).
# Incidencias: Matriz de indicencias con los mismos 329 casos pero solo con 10 variables (familia nuclear de Unamuno)
# UnamunoN: Marco de datos con 31 casos (personajes) y 6 variables (características de los personajes).
# Nodos: Marco de datos con 10 personajes (familia nuclear de Unamuno) y 7 variables (características de los personajes).

## Preparativos ----
### Carga la librerías necesarias ----
library(netCoin)

### Carga los datos para los gráficos de un fichero binario ----
data("Unamuno")


## a) Graficos de tarta ----

### Vector con el matrimonio y el hijo mayor ----
Fam <- c("Unamuno", "Lizarraga", "Fernando")

### Subconjunto de las tres personas mayores de la familia nuclear ----
Trio <- Unamuno[, Fam]

### Obtención del gráfico previa realización de la matriz de coicidencias ----
matcoin <- coin(Trio)
pies <- pieCoin(matcoin)
plot(pies, dir="~/temp1")

## b) Gráficos de barras ----

### Subconjuntos de incidencias y nodos ----
Incidencias <- Unamuno
Nodos       <- UnamunoN

### Gráficos de barras de coincidencias ----
B1  <- barCoin(Incidencias, nodes=Nodos, select="Unamuno",
               label = "etiqueta", language="es", cex=1.8, scalebar=TRUE)

### Gráficos de barras de coincidencias condicionales ----
B2  <- barCoin(Incidencias, nodes=Nodos, expected = TRUE, select="Unamuno",
               label = "etiqueta", language="es", cex=1.6, scalebar=TRUE)

### Gráfico de barras de coincidencias condicionales con significación ----
B3  <- barCoin(Incidencias, nodes=Nodos, expected = TRUE, significance = TRUE, select="Unamuno",
               label = "etiqueta", language="es", cex=1.6, scalebar=TRUE)

### Gráfico de barras de coincidencias condicionales con intervalos de confianza unidireccional ----
B4  <- barCoin(Incidencias, nodes=Nodos, expected = TRUE, significance = TRUE, confidence = TRUE, select="Unamuno",
               label = "etiqueta", language="es", cex=1.6, scalebar=TRUE)

### Gráfico de barras de coincidencias con intervalos de confianza bidireccionales ----
B5  <- barCoin(Incidencias, nodes=Nodos, expected = TRUE, significance = FALSE, confidence = TRUE, select="Unamuno",
               label = "etiqueta", language="es", cex=1.6, scalebar=TRUE)

## c) Conjunción de todos los grafos anteriores ----
serie <- multigraphCreate(Coincidencias=B1,
                          Condicional=B2,
                          Condicionales=B3,
                          Confianza=B4,
                          Intervalos=B5,
                          Red=G)


serie <- multigraphCreate(Coincidencias=B1,
                          Condicional=B2,
                          Condicionales=B3,
                          Confianza=B4,
                          Intervalos=B5)

plot(serie, dir="~/temp2")

## d) Diagrama de telaraña

X <- Incidencias[, c("Unamuno", "Lizarraga", "Fernando", "Pablo")]

Y <- as.data.frame(sapply(X, factor, levels=c(0,1), labels=c("No aparece","Aparece")))

CW <- cobCoin(Y)

plot(CW, dir="~/temp")

## e) Grafo de coincidencias a partir de una matriz de incidencias ----
G<-allNet(Incidencias ,nodes=Nodos, language="es", cex=1.6, frequency=T,
          main="Vínculos fotográficos de la familia de Unamuno", zoom=1.90,
          lwidth="Haberman",lweight="Haberman",ltext=NULL, controls=c(2,3),
          color="sexo", shape="generacion", # mode=c("heatmap","network"), orderA="generacion"
       )

plot(G, dir="~/temp3")

## f) Heatmap ----
H<-allNet(Incidencias ,nodes=Nodos, language="es", cex=1, frequency=T, size="",
          main="Vínculos fotográficos de la familia de Unamuno", zoom=1,
          lwidth="Haberman",lweight="Haberman",ltext=NULL,
          color="sexo", mode=c("heatmap"), intensity="Haberman"
)

plot(H, dir="~/temp4")

## g) Red con imágenes ----
### Prepara la variable que determina la posición del fichero con la imagen ----
Nodos$Persona <- paste0("./data/imagenes/", Nodos$nombre,".png")

I<-allNet(Incidencias ,nodes=Nodos, language="es", cex=1, frequency=T, size="",
          main="Vínculos fotográficos de la familia de Unamuno", zoom=2,
          note="Elaboración: Modesto Escobar (modesto@usal.es)", controls=c(2,3),
          lwidth="Haberman",lweight="Haberman",ltext=NULL,
          color="sexo", image="Persona",
)

plot(I, dir="~/temp5")
