# ********************************************************************************
# *************** Redes analíticas. Grafos de coincidencias y regresión **********
# ********************************************************************************
# ****************************** Madrid. CIS. 2023 *******************************
# ********************************************************************************
# ****************************** Capítulo 5 - Ejercicio 5.4 **********************

# 5. Gráfos de correlación y regresión ----

# Principales objetos:
# TST: Respuestas la pregunta “¿Quién soy yo?” clasificadas según Escobar (2018) .

## Preparativos ----
library(netCoin)
library(haven)
library(lavaan)
note<-'<p>Gráfico elaborado con netCoin. Escobar, M. et al. (2020). <i>netCoin: Interactive analytical networks</i>. Retrieved from <a href=\"https://CRAN.R-project.org/package=netCoin\"> CRAN.R packages</a>.</p>'

## a) Carga y preparación de los datos
TST <- read_dta('data/TST.dta', encoding="utf-8")
TST<-as_factor(TST)

## b) Regresión elemental
Modelo0<-"Atribución ~ Sentencias+país+hábitat+género+edad+estudios+trabajo, gaussian
         Objetividad ~ Sentencias+país+hábitat+género+edad+estudios+trabajo, gaussian
             Anclaje ~ Sentencias+país+hábitat+género+edad+estudios+trabajo, gaussian
          Sentencias ~            país+hábitat+género+edad+estudios+trabajo, gaussian"
M0<-glmCoin(Modelo0,TST, pmax=0.05)
#plot(M0, dir="~/Ejercicio5_4")

## c) Preparación de los nodos
N<-M0$nodes
N$clase <- ifelse(N$variable %in% c("Atribución", "Objetividad", "Anclaje", "Sentencias"),"Indicador", "V. sociodemográfica")


## c) Influencia sociodemográfica en el anclaje
Modelo1<-"Anclaje~ país+hábitat+género+edad+estudios+trabajo+Sentencias, gaussian"
M1<-glmCoin(Modelo1,TST, pmax=0.05, cex=1.4, size="%", controls=NULL, nodes=N, shape="clase", note=note, language="es", name="name",
             degreeFilter=1, distance=25, zoom=1.5, lweight="val.z",ltext="Estimador",
             main="<p>Influencia sociodemográfica en el anclaje (TST)")
#plot(M1, dir="~/Ejercicio5_4")

## d) Influencia en la atribución y la objetividad.

Modelo2<-"Atribución  ~ Sentencias+país+hábitat+género+edad+estudios+trabajo, gaussian"
Modelo3<-"Objetividad ~ Sentencias+país+hábitat+género+edad+estudios+trabajo, gaussian"

M2<-glmCoin(Modelo2,TST, pmax=0.05, cex=1.4, size="%", controls=NULL, nodes=N, shape="clase", note=note, language="es", name="name",
            degreeFilter=1, distance=25, zoom=1.5, lweight="val.z",ltext="Estimador", showLegend=FALSE,
            main="<p>Influencia sociodemográfica en la atribución (TST)")
M3<-glmCoin(Modelo3,TST, pmax=0.05, cex=1.4, size="%", controls=NULL, nodes=N, shape="clase", note=note, language="es", name="name",
            degreeFilter=1, distance=25, zoom=1.5, lweight="val.z",ltext="Estimador", showLegend=FALSE,
            main="<p>Influencia sociodemográfica en la objetividad (TST)")
plot(multi <- multigraphCreate("Atribución"  = M2,
                               "Objetividad" = M3, 
                               mode="parallel"))

## e) Influencia en el anclaje, la atribución, la objetividad y el número de sentencias.

A<-layoutGrid(N,"estudios:Universitario;género:Mujer;país:SA;país:Chile.Sentencias.Anclaje;Objetividad;Atribución.país:España,hábitat:Pueblo,edad:60-70,edad:50-59,trabajo:Tareas del hogar,trabajo:Estudiante,trabajo:Empleado,edad:16-29,país:UK")
Modelo4<-"Atribución  ~ país+hábitat+género+edad+estudios+trabajo+Sentencias, gaussian
          Objetividad ~ país+hábitat+género+edad+estudios+trabajo+Sentencias, gaussian
          Anclaje     ~ país+hábitat+género+edad+estudios+trabajo+Sentencias, gaussian
          Sentencias  ~ país+hábitat+género+edad+estudios+trabajo, gaussian"
plot(glmCoin(Modelo4,TST, pmax=0.05, cex=1.4, size="%", layout=A, controls=NULL, nodes=N, shape="clase", note=note, language="es", name="name",
             main="<p>Influencia sociodemográfica en los indicadores del TST</p><p>Sentencias, Objetividad, Atribución y Anclaje"), dir="~/TSTg3")



## f) Preparación de modelo de ecuaciones estructurales (path analysis)
TST2 <- dichotomize(TST, c("país", "hábitat", "género", "edad", "estudios", "trabajo"), add=FALSE)
TST2$`país:USA` <- TST2$`país:None` <- TST2$`edad:16-29` <- TST2$`edad:None` <- TST2$`trabajo:Empleado`<- TST2$`trabajo:None` <- NULL
TST2$`género:Hombre` <- TST2$`género:None` <- TST2$`hábitat:Pueblo` <- TST2$`hábitat:None` <- TST2$`estudios:Primarios` <- TST2$`estudios:None` <- NULL
TSTX <- cbind(TST[, c("Sentencias", "Objetividad", "Anclaje", "Atribución")],TST2)
names(TSTX) <- gsub(" ","",names(TSTX))
b <- rbind(matrix(c(0, -1, 1,  0, -1, 1, 1, 0.5), ncol=2), matrix(rep(NA, (ncol(TST2)*2)), ncol=2)) # Matriz de posicionamiento
B <- rbind(matrix(c(-1,  0, 0, 1, 0, -1, 1, 0  ), ncol=2), matrix(rep(NA, (ncol(TST2)*2)), ncol=2)) # Matriz de posicionamiento


## Elaboración del modelo de ecuaciones estructurales.
independents <- paste0("`",names(TST2), "`", collapse="+")
Modelo10 <- paste0(c("Sentencias~", 
                     "Atribución~Sentencias+", 
                     "Anclaje~Sentencias+Atribución+",
                     "Objetividad~Atribución+Anclaje+"), 
                     independents, collapse="\n")
L <- lavaan(Modelo10, na.omit(TSTX), auto.var=TRUE, auto.fix.first=TRUE, auto.cov.lv.x=TRUE)
P <- pathCoin(L, linkBipolar=TRUE, linkFilter="pvalue<.05", lcolor="beta", lwidth="beta", 
              degreeFilter=1, layout=B, color="variable", size="mean", labelSize="degree", 
              zoom=1.2, cex=1.5) 
P$nodes$mean[5:ncol(TST2)] <- P$nodes$mean[5:ncol(TST2)]*100
P$nodes$mean[2] <- P$nodes$mean[2]/2+50
P$nodes$variable <- c(rep("Indice",4), rep("País", 4), rep("Hábitat", 2), "Género", rep("Edad", 4), rep("Estudios", 2), rep("Trabajo", 5))
plot(P, dir="~/temp")
