# ********************************************************************************
# *************** Redes analíticas. Grafos de coincidencias y regresión **********
# ********************************************************************************
# ****************************** Madrid. CIS. 2023 *******************************
# ********************************************************************************
# ****************************** Capítulo 7 - Ejercicio 7.1 **********************

# Dimensiones y comunidades ----

# Principales objetos:
# Schwartz: Respuestas a los 21 ítems de la escala de Schwartz emitidas por la muestra de europeos.
# Scale: Características de los 21 ítems de la escala de Schwarta.

## Preparativos ----
library(netCoin)
# Carga de datos
load("data/Schwartz.RData")


## a) Disposiciones de los grafos ----

### A continuación aparecen (c1 y c2) dos modos distintos de organizar las coordenadas circulares. 
###    La primera (c1) se corresponde con la izquierda de la figura 3.
###    La segunda (c2) con la de la derecha de la misma figura
c1 <- c("Creatividad", "Riqueza", "Igualitarismo", "Popularidad", "Seguridad", "Novedad", "Obediencia", "Empatía", "Modestia", 
       "Diversión", "Independencia", "Ayuda", "Éxito", "Autoridad", "Riesgo", "Educación", "Respeto", "Fidelidad", "Ambientalismo", 
       "Costumbre", "Placer")
c2 <- c("Fidelidad", "Ayuda", "Igualitarismo", "Ambientalismo", "Empatía", "Independencia", "Creatividad", "Riesgo", "Novedad", "Placer", "Diversión",
         "Éxito", "Popularidad", "Riqueza", "Respeto", "Seguridad", "Autoridad", "Modestia", "Costumbre", "Obediencia", "Educación")

### A continuación aparecen (l1 y l2) dos modos distintos de organizar las coordenadas rectangulares. 
l1 <- "Riqueza,Respeto,Éxito,Popularidad.Independencia,Creatividad,Placer,Diversión,Novedad,Riesgo.Autoridad,Seguridad,Obediencia,Educación,Modestia,Costumbre.Igualitarismo,Ambientalismo,Empatía,Ayuda,Fidelidad"
l2 <- "Respeto,,,Placer,,Riesgo.,Popularidad,Éxito,Diversión,,Novedad.Riqueza;,,Independencia,Creatividad.Seguridad,,Modestia,Fidelidad,,Igualitarismo.,Educación,,,Empatía,.Autoridad,Obediencia,Costumbre,Ayuda,,Ambientalismo"
l2 <- "Riesgo,,Placer,,,Respeto.Novedad,,Diversión,Éxito,Popularidad,.Creatividad,Independencia,,,,Riqueza.Igualitarismo,,Fidelidad,Modestia,,Seguridad.,Empatía,,,Educación,.Ambientalismo,,Ayuda,Costumbre,Obediencia,Autoridad"

### Con estas instrucciones se elaboran sendas matrices (C2 y L2) de coordenadas
C2 <- layoutCircle(Scale, c2, name="Etiqueta", deg=7)
L2 <- layoutGrid(Scale, l2, name="Etiqueta")

## b) Construcción de grafos con disposición circular y rectangular. ----

## Se construye una lista para asignar a cada Subtipo una forma distinta, como entrada al argumento shape.
sh <- list(Subtipo=c(Autonomía="circle", Seguridad="circle", 
                     Universalismo= "diamond", Poder="diamond", 
                     Tradición="star", Estimulación="star", 
                     Benevolencia="triangle", Logro="triangle", 
                     Hedonismo="square", Conformidad="square"))
G1 <- netCorr(Schwartz, nodes=Scale, weight=weights, language="es", label="Etiqueta", 
              color="Tipo", shape=sh, lwidth="value", 
              layout=C2, linkFilter="value>.315", showAxes=TRUE, cex=1.6, 
              controls=NULL, showLegend=FALSE)
G2 <- netCorr(Schwartz, nodes=Scale, weight=weights, language="es", label="Etiqueta", 
              color="Tipo", shape=sh, lwidth="value",
              layout=L2, linkFilter="value>.315", showAxes=TRUE, cex=1.6, 
              controls=NULL, showLegend=FALSE)

multigraphCreate(Circular=G1, Reticular=G2, mode="parallel") |> plot(dir="d:/temp")

## c) Construcción de grafos con disposiciones estadísticas. ----

G3 <- netCorr(Schwartz, nodes=Scale, weight=weights, language="es", label="Etiqueta", 
              color="Tipo", shape=sh, lwidth="value", 
              layout="pc", linkFilter="value>.315", showAxes=TRUE, cex=1.6, 
              controls=NULL, showLegend=FALSE)
G4 <- netCorr(Schwartz, nodes=Scale, weight=weights, language="es", label="Etiqueta", 
              color="Tipo", shape=sh, lwidth="value", 
              layout="mds", linkFilter="value>.315", showAxes=TRUE, cex=1.6, 
              controls=NULL, showLegend=FALSE)

### Como el análisis de correspondencias no trabaja con variables cuantitativas se introduce una matriz binaria de incidencias.
schwartz <- ifelse(Schwartz>3,1,0)

G5 <-  allNet(schwartz, nodes=Scale, weight=weights, language="es", label="Etiqueta", 
              color="Tipo", shape=sh,
              layout="mca", linkFilter="Haberman>30", showAxes=TRUE, cex=1.6,
              controls=NULL, showLegend=FALSE)

## d) Mismos análisis con las coordenadas basadas en criterios físicos.

G6 <- netCorr(Schwartz, nodes=Scale, weight=weights, language="es", label="Etiqueta", 
              color="Tipo", shape=sh, lwidth="value", 
              layout="kamada", linkFilter="value>.315", showAxes=TRUE, cex=1.6, 
              controls=NULL, showLegend=FALSE)
G7 <- netCorr(Schwartz, nodes=Scale, weight=weights, language="es", label="Etiqueta", 
              color="Tipo", shape=sh, lwidth="value", 
              layout="fruchterman", linkFilter="value>.315", showAxes=TRUE, cex=1.6, 
              controls=NULL, showLegend=FALSE)
G8 <- netCorr(Schwartz, nodes=Scale, weight=weights, language="es", label="Etiqueta", 
              color="Tipo", shape=sh, lwidth="value", 
              layout="force", linkFilter="value>.315", showAxes=TRUE, cex=1.6, 
              controls=NULL, showLegend=FALSE)

multigraphCreate(Circular=G1, Reticular=G2,
                 Componentes=G3, MDS=G4, MCA=G5,
                 "Kamada-Kawai"=G6, "Fruchterman-Reingold"=G7, "AtlasForce2"=G8) |> plot(dir="~/temp")

G9 <- netCorr(Schwartz, nodes=Scale, weight=weights, language="es", label="Etiqueta", 
              color="Tipo", shape="community", lwidth="value", 
              community="fast", criteria="value", minL=.315, showAxes=TRUE, cex=1.6, 
              repulsion= 70, zoom=.7, controls=NULL, showLegend=FALSE)
G10 <- netCorr(Schwartz, nodes=Scale, weight=weights, language="es", label="Etiqueta", 
              color="Tipo", shape="community", lwidth="value", 
              community="fast", criteria="value", minL=.25, showAxes=TRUE, cex=1.6, 
              repulsion= 70, zoom=.7, controls=NULL, showLegend=FALSE)

multigraphCreate("r>0,315"=G9, "r>0,25"=G10, mode="parallel") |> plot(dir="~/temp")
